# Rules for Unix toolchain

INIT_DEFAULT_OUTPUT = Makefile
INIT_KEYWORDS       = unix

### Standard Application
begin app
OUTPUT_$(NAME) := $(NAME)
OBJECT_EXT     := o

$(OUTPUT): $(OBJECTS) $(OUTPUT_$(DEPEND)) $(LIBDEPEND)
        $(CXX) $(LDFLAGS) -o $(OUTPUT) $(OBJECTS) $(LINK_$(DEPEND)) $(LIBS)

clean:
	$(RM) $(OBJECTS)

distclean:
        $(RM) $(OUTPUT)

ALL_TARGETS += $(OUTPUT)
end


### Static Library
begin lib
OUTPUT_$(NAME) := lib$(NAME).a
OBJECT_EXT     := o
LINK_$(NAME)   := -L. -l$(NAME)

$(OUTPUT): $(OBJECTS) $(OUTPUT_$(DEPEND))
        $(AR) cru $(OUTPUT) $(OBJECTS) $(OUTPUT_$(DEPEND))

distclean:
        $(RM) $(OUTPUT)

clean:
	$(RM) $(OBJECTS)

ALL_TARGETS += $(OUTPUT)
end


### DLL
begin dll
OUTPUT_$(NAME) := lib$(NAME).so
OBJECT_EXT     := lo
LINK_$(NAME)   := -L. -l$(NAME)

$(OUTPUT): $(OBJECTS) $(OUTPUT_$(DEPEND))
	$(CC) -o $(OUTPUT) -shared $(OBJECTS) $(OUTPUT_$(DEPEND))

distclean:
	$(RM) $(OUTPUT)

clean:
	$(RM) $(OBJECTS)

ALL_TARGETS += $(OUTPUT)
end


### Object file
begin obj
OUTPUT_$(NAME) := $(NAME).o
OBJECT_EXT     := o
LINK_$(NAME)   := $(OUTPUT)

$(OUTPUT): $(OBJECTS) $(OUTPUT_$(DEPEND))
	$(LD) -r -o $(OUTPUT) $(OBJECTS) $(OUTPUT_$(DEPEND))

distclean:
        $(RM) $(OUTPUT)

clean:
	$(RM) $(OBJECTS)

ALL_TARGETS += $(OUTPUT)
end


### Subproject
begin subproject
OBJECT_EXT     := o
OUTPUT_$(NAME) := $(OBJECTS) $(OUTPUT_$(DEPEND))
LINK_$(NAME)   := $(OBJECTS) $(LINK_$(DEPEND))

clean:
        $(RM) $(OBJECTS)
end


### Prebuilt library
begin prebuilt-lib
OUTPUT_$(NAME) :=
LINK_$(NAME) := -L$(LIBDIR) -l$(NAME)
end


### Basic Rules

# C compiler:
.c.o:
	$(CC) $(CFLAGS) -o $@ -c $<

.c.s:
	$(CC) $(CFLAGS) -o $@ -S $<

.c.lo:
	$(CC) -fPIC $(CXXFLAGS) -o $@ -c $<

# C++ compiler:
.cc.o:
	$(CXX) $(CXXFLAGS) -o $@ -c $<

.cc.lo:
	$(CXX) -fPIC $(CXXFLAGS) -o $@ -c $<

.cpp.o:
	$(CXX) $(CXXFLAGS) -o $@ -c $<

.cpp.lo:
	$(CXX) -fPIC $(CXXFLAGS) -o $@ -c $<

.cc.s:
	$(CXX) $(CXXFLAGS) -o $@ -S $<

.cpp.s:
	$(CXX) $(CXXFLAGS) -o $@ -S $<

# Administrativa:
distclean: clean

.PHONY: clean distclean
