/**
  *  \file resmgr/res-wp.cc
  *  \brief Winplan Resource Provider
  *
  *  (c) 2001-2008 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "resmgr/res-wp.h"
#include "cpluslib/format.h"
#include "gfx/pixmap.h"
#include "resmgr/resid.h"

/*! \class ResProviderWinplanBitmaps
    \brief Winplan Resource Provider

    This resource provider provides access to a Winplan "bmp" directory.
    It reads the ship pictures.

    Provides res::ship(n). */

ResProviderWinplanBitmaps::ResProviderWinplanBitmaps(Ptr<Directory> dir)
    : dir(dir)
{ }

ResProviderWinplanBitmaps::ResProviderWinplanBitmaps(string_t s)
    : dir(Directory::openDir(s))
{ }

ResProviderWinplanBitmaps::~ResProviderWinplanBitmaps()
{ }

void
ResProviderWinplanBitmaps::loadPixmap(ResManager& mgr, ResId id)
{
    if (id.isElem(res::ship, 1))
        mgr.addPixmap(id,
                      loadImage(dir->openFileNT(format("vpl%d.bmp", id.getId1()),
                                                Stream::C_READ)));
}
