/**
  *  \file u/t_game_fcode.cc
  *
  *  (c) 2001-2008 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/fcode.h"
#include "u/t_game.h"
#include "game/host.h"

void
GameFcodeTestSuite::testFCode()
{
    GFCode mkt("mkt", "sc,make torps");
    GFCode lfm("lfm", "sc+9ab,make fighters");
    GFCode att("ATT", "p,attack");

    TS_ASSERT_EQUALS(mkt.getFCode(), "mkt");
    TS_ASSERT(mkt.getRaceMask().contains(1));
    TS_ASSERT(mkt.getRaceMask().contains(2));
    TS_ASSERT(mkt.getRaceMask().contains(10));
    TS_ASSERT_EQUALS(mkt.getDescription(), "make torps");

    TS_ASSERT(!lfm.getRaceMask().contains(1));
    TS_ASSERT(!lfm.getRaceMask().contains(8));
    TS_ASSERT(lfm.getRaceMask().contains(9));
    TS_ASSERT(lfm.getRaceMask().contains(10));
    TS_ASSERT(lfm.getRaceMask().contains(11));

    TS_ASSERT(GFCode::isNumeric("000"));
    TS_ASSERT(!GFCode::isNumeric("00x"));
    TS_ASSERT(!GFCode::isNumeric("x00"));
    TS_ASSERT(!GFCode::isNumeric("+00"));
    TS_ASSERT(GFCode::isNumeric("999"));

    host.clear();
    host.setHostVersion(MKVERSION(3,22,40), ht_Host);
    TS_ASSERT(!GFCode::isNumeric("-11"));
    TS_ASSERT(!GFCode::isNumeric("--1"));
    TS_ASSERT(!GFCode::isNumeric("1"));
    TS_ASSERT(!GFCode::isNumeric(" 1"));
    TS_ASSERT(!GFCode::isNumeric("1 "));
    TS_ASSERT(!GFCode::isNumeric(" 1 "));

    host.setHostVersion(MKVERSION(4,0,0), ht_PHost);
    TS_ASSERT(GFCode::isNumeric("-11"));
    TS_ASSERT_EQUALS(GFCode::getNumericValue("-11"), -11);
    TS_ASSERT(!GFCode::isNumeric("--1"));
    TS_ASSERT(!GFCode::isNumeric("1"));
    TS_ASSERT(!GFCode::isNumeric(" 1"));
    TS_ASSERT(!GFCode::isNumeric("1 "));
    TS_ASSERT(!GFCode::isNumeric(" 1 "));

    host.setHostVersion(MKVERSION(4,0,8), ht_PHost);
    TS_ASSERT(GFCode::isNumeric("-11"));
    TS_ASSERT_EQUALS(GFCode::getNumericValue("-11"), -11);
    TS_ASSERT(!GFCode::isNumeric("--1"));
    TS_ASSERT(GFCode::isNumeric("1"));
    TS_ASSERT_EQUALS(GFCode::getNumericValue("1"), 1);
    TS_ASSERT(GFCode::isNumeric(" 1"));
    TS_ASSERT_EQUALS(GFCode::getNumericValue(" 1"), 1);
    TS_ASSERT(GFCode::isNumeric("1 "));
    TS_ASSERT_EQUALS(GFCode::getNumericValue("1 "), 1);
    TS_ASSERT(GFCode::isNumeric(" 1 "));
    TS_ASSERT_EQUALS(GFCode::getNumericValue(" 1 "), 1);

    host.setHostVersion(MKVERSION(3,4,9), ht_PHost);
    TS_ASSERT(!GFCode::isNumeric(" 1 "));

    host.setHostVersion(MKVERSION(3,4,11), ht_PHost);
    TS_ASSERT(GFCode::isNumeric(" 1 "));
}
