/**
  *  \file u/t_ui_richtext.cc
  */

#include "ui/richtext.h"
#include "u/t_ui.h"

namespace {
    class AttributeCounter : public RichTextVisitor {
        int start, end;
     public:
        AttributeCounter()
            : start(0), end(0)
            { }
        bool handleText(string_t)
            { return true; }
        bool startAttribute(const RichTextAttribute*)
            { ++start; return true; }
        bool endAttribute(const RichTextAttribute*)
            { ++end; return true; }

        void check(int att)
            {
                TS_ASSERT_EQUALS(start, end);
                TS_ASSERT_EQUALS(start, att);
            }
    };
}

void
UiRichTextTestSuite::testRichText()
{
    RichText s1("hello, world");
    TS_ASSERT_EQUALS(s1.size(), 12);
    TS_ASSERT_EQUALS(s1.getNumAttributes(), 0);
    static_cast<AttributeCounter&>(AttributeCounter().visit(s1)).check(0);

    RichText s2(UIColor::tc_Static, "static text");
    TS_ASSERT_EQUALS(s2.size(), 11);
    TS_ASSERT_EQUALS(s2.getNumAttributes(), 1);
    static_cast<AttributeCounter&>(AttributeCounter().visit(s2)).check(1);

    RichText s3 = s1 + s2 + "raw" + RichText("background").withAttribute(new RichTextColorAttribute(UIColor::tc_Background));
    TS_ASSERT_EQUALS(s3.size(), 36);
    TS_ASSERT_EQUALS(s3.getNumAttributes(), 2);
    static_cast<AttributeCounter&>(AttributeCounter().visit(s3)).check(2);

    TS_ASSERT_EQUALS(s3.substr(10, 2).getNumAttributes(), 0);
    TS_ASSERT_EQUALS(s3.substr(10, 3).getNumAttributes(), 1);
    TS_ASSERT_EQUALS(s3.substr(12, 2).getNumAttributes(), 1);
}
